import { IAutoScalingGroup } from '@aws-cdk/aws-autoscaling';
import { CronOptions } from '@aws-cdk/aws-events';
import { Construct } from '@aws-cdk/core';
/**
 * Props for the NightNight construct.
 *
 * @stability stable
 */
export interface NightyNightForAsgProps {
    /**
     * An option CronOptions to specify the time of day to scale.
     *
     * @default {
     * day: '*',
     * hour: '4',
     * minute: '0'
     * }
     * @stability stable
     */
    readonly schedule?: CronOptions;
    /**
     * the AutoScalingGroup you'd like to change the instance count on.
     *
     * @stability stable
     */
    readonly autoScalingGroup: IAutoScalingGroup;
    /**
     * Desired capacity.
     *
     * @stability stable
     */
    readonly desiredCapacity: number;
}
/**
 * A construct that will build a Lambda and a CloudWatch Rule (cron schedule) that will set the given ASG's desired capacity.
 *
 * Typically used when you've got and ASG that you can scale during set hours.
 *
 * @stability stable
 */
export declare class NightyNightForAsg extends Construct {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: NightyNightForAsgProps);
}
